# Galatasaray

Everything about the Galatasaray from cli!

## Installation

Open your terminal and run:

```shell
pip install galatasaray
```

## Usage

Open your terminal and run:

```shell
galatasaray
```

![galatasaray](./docs/img/screenshot.png)
